plugin top-level property
The plugin entry point.
The Dart Analysis Server discovers an analyzer plugin by importing
lib/main.dart and reading this top-level plugin variable.
Implementation
final plugin = VibeCheckPlugin();
The plugin entry point.
The Dart Analysis Server discovers an analyzer plugin by importing
lib/main.dart and reading this top-level plugin variable.
final plugin = VibeCheckPlugin();